@@ -25,32 +25,29 @@ class CreateSimilarSecurityEventsQueryTaskRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'Sas', '2018-12-03', 'CreateSimilarSecurityEventsQueryTask')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_ResourceOwnerId(self):
+	def get_ResourceOwnerId(self): # Long
 		return self.get_query_params().get('ResourceOwnerId')
 
-	def set_ResourceOwnerId(self,ResourceOwnerId):
-		self.add_query_param('ResourceOwnerId',ResourceOwnerId)
-
-	def get_SourceIp(self):
+	def set_ResourceOwnerId(self, ResourceOwnerId):  # Long
+		self.add_query_param('ResourceOwnerId', ResourceOwnerId)
+	def get_SourceIp(self): # String
 		return self.get_query_params().get('SourceIp')
 
-	def set_SourceIp(self,SourceIp):
-		self.add_query_param('SourceIp',SourceIp)
-
-	def get_SecurityEventId(self):
+	def set_SourceIp(self, SourceIp):  # String
+		self.add_query_param('SourceIp', SourceIp)
+	def get_SecurityEventId(self): # Long
 		return self.get_query_params().get('SecurityEventId')
 
-	def set_SecurityEventId(self,SecurityEventId):
-		self.add_query_param('SecurityEventId',SecurityEventId)
-
-	def get_SimilarEventScenarioCode(self):
+	def set_SecurityEventId(self, SecurityEventId):  # Long
+		self.add_query_param('SecurityEventId', SecurityEventId)
+	def get_SimilarEventScenarioCode(self): # String
 		return self.get_query_params().get('SimilarEventScenarioCode')
 
-	def set_SimilarEventScenarioCode(self,SimilarEventScenarioCode):
-		self.add_query_param('SimilarEventScenarioCode',SimilarEventScenarioCode)
\ No newline at end of file
+	def set_SimilarEventScenarioCode(self, SimilarEventScenarioCode):  # String
+		self.add_query_param('SimilarEventScenarioCode', SimilarEventScenarioCode)
