@@ -25,20 +25,19 @@ class DescribeVersionConfigRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'Sas', '2018-12-03', 'DescribeVersionConfig')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_SourceIp(self):
+	def get_SourceIp(self): # String
 		return self.get_query_params().get('SourceIp')
 
-	def set_SourceIp(self,SourceIp):
-		self.add_query_param('SourceIp',SourceIp)
-
-	def get_ResourceDirectoryAccountId(self):
+	def set_SourceIp(self, SourceIp):  # String
+		self.add_query_param('SourceIp', SourceIp)
+	def get_ResourceDirectoryAccountId(self): # String
 		return self.get_query_params().get('ResourceDirectoryAccountId')
 
-	def set_ResourceDirectoryAccountId(self,ResourceDirectoryAccountId):
-		self.add_query_param('ResourceDirectoryAccountId',ResourceDirectoryAccountId)
\ No newline at end of file
+	def set_ResourceDirectoryAccountId(self, ResourceDirectoryAccountId):  # String
+		self.add_query_param('ResourceDirectoryAccountId', ResourceDirectoryAccountId)
